@@ -37,6 +37,16 @@ class Focus:
     def __repr__(self):
         return self.r
 
+    def __hash__(self):
+        """
+        Thanks to the hash, we can use a focus as a dictionary key:
+
+            >>> d = {Focus.DIRECT: 42, Focus.FORWARD_FOCUSED:51}
+            >>> d[Focus.DIRECT]
+            42
+        """
+        return hash(self.r)
+
     def __eq__(self, other):
         """
             >>> Focus.DIRECT == Focus.DIRECT
