@@ -1,3 +1,4 @@
+import pytest
 from fractions import Fraction
 from poisson_approval import ProfileNoisyDiscrete, StrategyOrdinal, PLURALITY, ANTI_PLURALITY
 
@@ -7,6 +8,11 @@ def test_normalization():
     assert profile.abc == 0.5
 
 
+def test_epsilon_zero():
+    with pytest.raises(ValueError):
+        profile = ProfileNoisyDiscrete({('abc', 0.2): .5, ('acb', 0.4): .5}, noise=0)
+
+
 def test_plurality():
     """
         >>> profile = ProfileNoisyDiscrete({('abc', 0.2, 0.01): 1, ('acb', 0.4, 0.01): 1}, voting_rule=PLURALITY)
